==> badi_users-0.8.9.tar.gz: badi_users-0.8.9/badi_ticket/views.py <==
from badi_utils.dynamic import DynamicCreateView, DynamicListView, DynamicUpdateView
from badi_ticket.models import Message, Ticket
from django.contrib.auth import get_user_model

User = get_user_model()


class TicketListView(DynamicListView):
    # permission_required = ROLES_ADMIN_TEACHER
    permission_required = True
    model = Ticket
    datatable_cols = ['#', 'کاربر', 'عنوان', 'تاریخ ایجاد', 'بسته شده', ]


class TicketCreateView(DynamicCreateView):
    model = Ticket
    success_url = '/ticket/ticket/list'
    permission_required = True
    datatable_cols = model().get_datatable_verbose_names()
    # permission_required = ROLES_ADMIN_TEACHER
    form_fields = ['title', 'writer']

    # updateURL = '/ticket/ticket/update/0'

    def get_extra_context(self, context):
        context['form'].fields['writer'].queryset = User.objects.none()
        return super().get_extra_context(context)


class TicketUpdateView(DynamicUpdateView):
    model = Ticket
    success_url = '/dashboard/ticket/ticket/list'
    form_fields = ['title', 'writer', 'is_closed']

    def get_extra_context(self, context):
        context['form'].fields['writer'].queryset = User.objects.none()
        context['api_url'] = '/api/v1/ticket/'
        context['successURL'] = self.success_url
        return super().get_extra_context(context)


class MessageListView(DynamicListView):
    # permission_required = ROLES_ADMIN_TEACHER
    template_name = 'ticket/message_list.html'
    permission_required = True
    model = Message
    datatable_cols = ['#', 'نام کاربری', 'نام', 'نام خانوادگی', 'نقش']

    def get_extra_context(self, context):
        context['pk'] = self.kwargs['pk']
        return super().get_extra_context(context)


class MessageCreateView(DynamicCreateView):
    model = Message
    success_url = '/message/list'
    datatableEnable = False
    permission_required = True

==> badi_users-0.9.2.tar.gz: badi_users-0.9.2/badi_ticket/views.py <==
from badi_utils.dynamic import DynamicCreateView, DynamicListView, DynamicUpdateView
from badi_ticket.models import Message, Ticket
from django.contrib.auth import get_user_model
from django.utils.translation import gettext_lazy as _

User = get_user_model()


class TicketListView(DynamicListView):
    # permission_required = ROLES_ADMIN_TEACHER
    permission_required = True
    model = Ticket
    datatable_cols = ['#', _('Member'), _('Title'), _('Status'), _("Created at")]


class TicketCreateView(DynamicCreateView):
    model = Ticket
    success_url = '/ticket/ticket/list'
    permission_required = True
    datatable_cols = ['#', _('Member'), _('Title'), _('Status'), _("Created at")]
    # permission_required = ROLES_ADMIN_TEACHER
    form_fields = ['title', 'writer']

    # updateURL = '/ticket/ticket/update/0'

    def get_extra_context(self, context):
        context['form'].fields['writer'].queryset = User.objects.none()
        return super().get_extra_context(context)


class TicketUpdateView(DynamicUpdateView):
    model = Ticket
    success_url = '/dashboard/ticket/ticket/list'
    form_fields = ['title', 'writer', 'is_closed']

    def get_extra_context(self, context):
        context['form'].fields['writer'].queryset = User.objects.none()
        context['api_url'] = '/api/v1/ticket/'
        context['successURL'] = self.success_url
        return super().get_extra_context(context)


class MessageListView(DynamicListView):
    # permission_required = ROLES_ADMIN_TEACHER
    template_name = 'ticket/message_list.html'
    permission_required = True
    model = Message
    datatable_cols = ['#', 'نام کاربری', 'نام', 'نام خانوادگی', 'نقش']

    def get_extra_context(self, context):
        context['pk'] = self.kwargs['pk']
        return super().get_extra_context(context)


class MessageCreateView(DynamicCreateView):
    model = Message
    success_url = '/message/list'
    datatableEnable = False
    permission_required = True
